# -*- coding: utf-8 -*-
#
# Copyright (c) 2020, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.mixins._delegation import DelegateCallbackMixin as _DelegateCallbackMixin
from htf.mixins._delegation import DelegateMixin as _DelegateMixin
from htf.mixins._delegation import DelegatorMixin as _DelegatorMixin


class DelegateCallbackMixin(_DelegateCallbackMixin):
    """
    ``DelegateCallbackMixin`` gives the possibility to user define
    setter and getter methods using a :class:`DelegateMixin`.
    """

    def __init__(self, set_callback, get_callback):
        """
        Args:
            set_callback (callable): the method to be called as a setter.
            get_callback (callable): the method to be called as a getter.
        """
        super(DelegateCallbackMixin, self).__init__(set_callback=set_callback, get_callback=get_callback)


class DelegateMixin(_DelegateMixin):
    """
    ``DelegateMixin`` defines :func:`set` and :func:`get` as methods that have
    to be overwritten by subclass.
    """

    def get(self):
        """
        The getter for a delegate.

        Note:
            This method is abstract.
        """
        return super(DelegateMixin, self).get()

    def set(self, value):
        """
        The setter for a delegate.

        Args:
            value: the value to be set.

        Note:
            This method is abstract.
        """
        return super(DelegateMixin, self).set(value=value)


class DelegatorMixin(_DelegatorMixin):
    """
    The ``DelegatorMixin`` automatically delegates calls for :func:`DelegateMixin.set` and
     :func:`DelegateMixin.get` to its members if they are instances of :class:`DelegateMixin`.
    """

