# -*- coding: utf-8 -*-
#
# Copyright (c) 2020, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from __future__ import absolute_import, division, print_function, unicode_literals

from htf.powersupply._manson_hcs_3xxx import MansonHCS3xxx as _MansonHCS3xxx
from htf.powersupply._manson_hcs_3xxx import TimeoutException as _TimeoutException


class MansonHCS3xxx(_MansonHCS3xxx):
    """
    ``MansonHCS3xxx`` is a hardware abstraction to the Manson HCS-3xxx power supply family using a UART to control it.

    ``MansonHCS3xxx`` uses ``DelegatorMixin`` to automatically set and read it's members `voltage` and `current`.
    """

    def __init__(self, port, decimal_places_for_current=1, debug=False):
        """
        Args:
            port (str): the comport to be used, eg. "COM3", 3 or "/dev/ttyUSB0", etc.
            decimal_places_for_current=1 (int): the number of decimal places for the current.
                HCS-3100, 3150, 3200 and 3202 have one decimal place. HCS-3102, 3014 and 3204 have two decimal places.
            debug=False (bool): if set to `True` debugging is enabled
        """
        super(MansonHCS3xxx, self).__init__(port=port, decimal_places_for_current=decimal_places_for_current, debug=debug)

    def close(self):
        """
        Close the serial member. This method is automatically called when :func:`__del__` is called.
        """
        return super(MansonHCS3xxx, self).close()

    def disable_output(self):
        """
        Disable output.
        """
        return super(MansonHCS3xxx, self).disable_output()

    disableOutput = disable_output

    def enable_output(self):
        """
        Enable output.
        """
        return super(MansonHCS3xxx, self).enable_output()

    enableOutput = enable_output

    def get_current(self):
        """
        Read the current current from device and return the result.

        Returns:
            float: the current current.
        """
        return super(MansonHCS3xxx, self).get_current()

    getCurrent = get_current

    def get_display_voltage_current_and_status(self):
        """
        Get the display voltage, current and status.

        Returns:
            dict: a dictionary containing "voltage", "current" and "status".
        """
        return super(MansonHCS3xxx, self).get_display_voltage_current_and_status()

    getDisplayVoltageCurrentAndStatus = get_display_voltage_current_and_status

    def get_preset_maximum_current(self):
        """
        Get preset maximum current for current preset.

        Returns:
            int: the preset maximum current.
        """
        return super(MansonHCS3xxx, self).get_preset_maximum_current()

    getPresetMaximumCurrent = get_preset_maximum_current

    def get_preset_maximum_voltage(self):
        """
        Get preset maximum voltage for current preset.

        Returns:
            int: the preset maximum voltage.
        """
        return super(MansonHCS3xxx, self).get_preset_maximum_voltage()

    getPresetMaximumVoltage = get_preset_maximum_voltage

    def get_preset_maximum_voltage_and_current(self):
        """
        Get the preset maximum voltage and current.

        Returns:
            dict: a dictionary containing "voltage" and "current".
        """
        return super(MansonHCS3xxx, self).get_preset_maximum_voltage_and_current()

    getPresetMaximumVoltageAndCurrent = get_preset_maximum_voltage_and_current

    def get_preset_voltage_and_current(self):
        """
        Get the preset voltage and current.

        Returns:
            dict: a dictionary containing "voltage" and "current".
        """
        return super(MansonHCS3xxx, self).get_preset_voltage_and_current()

    getPresetVoltageAndCurrent = get_preset_voltage_and_current

    def get_presets(self):
        """
        Get three voltage-current presets.

        Returns:
            dict: a dictionary containing "voltage", "current" and "P<preset>".
        """
        return super(MansonHCS3xxx, self).get_presets()

    getPresets = get_presets

    def get_voltage(self):
        """
        Read current voltage from device and return the result.

        Returns:
            float: the current voltage.
        """
        return super(MansonHCS3xxx, self).get_voltage()

    getVoltage = get_voltage

    def load_preset(self, preset):
        """
        Load preset ``preset``.

        Args:
            preset (int): may be 0, 1, or 2.
        """
        return super(MansonHCS3xxx, self).load_preset(preset=preset)

    loadPreset = load_preset

    def preset_maximum_current(self, current):
        """
        Set maximum voltage for current preset.
        """
        return super(MansonHCS3xxx, self).preset_maximum_current(current=current)

    presetMaximumCurrent = preset_maximum_current

    def preset_maximum_voltage(self, voltage):
        """
        Set maximum voltage for current preset.
        """
        return super(MansonHCS3xxx, self).preset_maximum_voltage(voltage=voltage)

    presetMaximumVoltage = preset_maximum_voltage

    def query(self, query, answer_lines=1):
        """
        Send a command and wait for the answer.

        Args:
            query (str): the query to be sent.
            answer_lines=1 (int): the number of lines to be received.

        Returns:
            str: the answer line(s).

        Raises:
            manson_hcs_3xxx.TimeoutException: if a communication time-out occurred.
        """
        return super(MansonHCS3xxx, self).query(query=query, answer_lines=answer_lines)

    def set_current(self, current):
        """
        Set the output current to ``current``.

        Args:
            current (int, float or str): the current in units of amperes as int(), float() or string, eg. 0, 0.5,
             "0.5" or even "0.5 mA" work.
        """
        return super(MansonHCS3xxx, self).set_current(current=current)

    setCurrent = set_current

    def set_voltage(self, voltage):
        """
        Set the output voltage to ``voltage``.

        Args:
            voltage (int, float or str): the voltage in units of volts as int(), float() or string, eg. 23, 23.0,
                "23.0" or even "23.0 V" work.
                `voltage` may have on decimal point. If `voltage` is ``None`` the output is disabled.
        """
        return super(MansonHCS3xxx, self).set_voltage(voltage=voltage)

    setVoltage = set_voltage

    def store_presets(self, presets):
        """
        Store three voltage-current presets.

        Args:
            presets (dict): a dictionary containing the key P1, P2 and P3. Each key contains "voltage" and
             "current" keys.
        """
        return super(MansonHCS3xxx, self).store_presets(presets=presets)

    storePresets = store_presets


class TimeoutException(_TimeoutException):
    """
    Exception that is raised if a communication time-out occurred.
    """

